@@ -8,15 +8,13 @@
 
 #include <fcntl.h>
 #include <grp.h>
-#include <sys/stat.h>
 
 
-static int	check_data_dir(migratorContext *ctx, const char *pg_data);
-static const char *getErrorText(int errNum);
 static void checkBinDir(migratorContext *ctx, ClusterInfo *cluster);
 static int check_exec(migratorContext *ctx, const char *dir, const char *cmdName,
 		   const char *alternative);
 static const char *validate_exec(const char *path);
+static int	check_data_dir(migratorContext *ctx, const char *pg_data);
 
 
 /*
@@ -55,6 +53,89 @@ exec_prog(migratorContext *ctx, bool throw_error, const char *fmt,...)
 }
 
 
+/*
+ * verify_directories()
+ *
+ * does all the hectic work of verifying directories and executables
+ * of old and new server.
+ *
+ * NOTE: May update the values of all parameters
+ */
+void
+verify_directories(migratorContext *ctx)
+{
+	prep_status(ctx, "Checking old data directory (%s)", ctx->old.pgdata);
+	if (check_data_dir(ctx, ctx->old.pgdata) != 0)
+		pg_log(ctx, PG_FATAL, "Failed\n");
+	checkBinDir(ctx, &ctx->old);
+	check_ok(ctx);
+
+	prep_status(ctx, "Checking new data directory (%s)", ctx->new.pgdata);
+	if (check_data_dir(ctx, ctx->new.pgdata) != 0)
+		pg_log(ctx, PG_FATAL, "Failed\n");
+	checkBinDir(ctx, &ctx->new);
+	check_ok(ctx);
+}
+
+
+/*
+ * checkBinDir()
+ *
+ *	This function searches for the executables that we expect to find
+ *	in the binaries directory.	If we find that a required executable
+ *	is missing (or secured against us), we display an error message and
+ *	exit().
+ */
+static void
+checkBinDir(migratorContext *ctx, ClusterInfo *cluster)
+{
+	check_exec(ctx, cluster->bindir, "postgres", "edb-postgres");
+	check_exec(ctx, cluster->bindir, "pg_ctl", NULL);
+	check_exec(ctx, cluster->bindir, "pg_dumpall", NULL);
+
+#ifdef EDB_NATIVE_LANG
+	/* check for edb-psql first because we need to detect EDB AS */
+	if (check_exec(ctx, cluster->bindir, "edb-psql", "psql") == 1)
+	{
+		cluster->psql_exe = "edb-psql";
+		cluster->is_edb_as = true;
+	}
+	else
+#else
+	if (check_exec(ctx, cluster->bindir, "psql", NULL) == 1)
+#endif
+		cluster->psql_exe = "psql";
+}
+
+
+/*
+ * is_server_running()
+ *
+ * checks whether postmaster on the given data directory is running or not.
+ * The check is performed by looking for the existence of postmaster.pid file.
+ */
+bool
+is_server_running(migratorContext *ctx, const char *datadir)
+{
+	char		path[MAXPGPATH];
+	int			fd;
+
+	snprintf(path, sizeof(path), "%s/postmaster.pid", datadir);
+
+	if ((fd = open(path, O_RDONLY)) < 0)
+	{
+		if (errno != ENOENT)
+			pg_log(ctx, PG_FATAL, "\ncould not open file \"%s\" for reading\n",
+				   path);
+
+		return false;
+	}
+
+	close(fd);
+	return true;
+}
+
+
 /*
  * check_exec()
  *
@@ -94,89 +175,6 @@ check_exec(migratorContext *ctx, const char *dir, const char *cmdName,
 }
 
 
-/*
- * checkBinDir()
- *
- *	This function searches for the executables that we expect to find
- *	in the binaries directory.	If we find that a required executable
- *	is missing (or secured against us), we display an error message and
- *	exit().
- */
-static void
-checkBinDir(migratorContext *ctx, ClusterInfo *cluster)
-{
-	check_exec(ctx, cluster->bindir, "postgres", "edb-postgres");
-	check_exec(ctx, cluster->bindir, "pg_ctl", NULL);
-	check_exec(ctx, cluster->bindir, "pg_dumpall", NULL);
-
-#ifdef EDB_NATIVE_LANG
-	/* check for edb-psql first because we need to detect EDB AS */
-	if (check_exec(ctx, cluster->bindir, "edb-psql", "psql") == 1)
-	{
-		cluster->psql_exe = "edb-psql";
-		cluster->is_edb_as = true;
-	}
-	else
-#else
-	if (check_exec(ctx, cluster->bindir, "psql", NULL) == 1)
-#endif
-		cluster->psql_exe = "psql";
-}
-
-
-/*
- * verify_directories()
- *
- * does all the hectic work of verifying directories and executables
- * of old and new server.
- *
- * NOTE: May update the values of all parameters
- */
-void
-verify_directories(migratorContext *ctx)
-{
-	prep_status(ctx, "Checking old data directory (%s)", ctx->old.pgdata);
-	if (check_data_dir(ctx, ctx->old.pgdata) != 0)
-		pg_log(ctx, PG_FATAL, "Failed\n");
-	checkBinDir(ctx, &ctx->old);
-	check_ok(ctx);
-
-	prep_status(ctx, "Checking new data directory (%s)", ctx->new.pgdata);
-	if (check_data_dir(ctx, ctx->new.pgdata) != 0)
-		pg_log(ctx, PG_FATAL, "Failed\n");
-	checkBinDir(ctx, &ctx->new);
-	check_ok(ctx);
-}
-
-
-/*
- * is_server_running()
- *
- * checks whether postmaster on the given data directory is running or not.
- * The check is performed by looking for the existence of postmaster.pid file.
- */
-bool
-is_server_running(migratorContext *ctx, const char *datadir)
-{
-	char		path[MAXPGPATH];
-	int			fd;
-
-	snprintf(path, sizeof(path), "%s/postmaster.pid", datadir);
-
-	if ((fd = open(path, O_RDONLY)) < 0)
-	{
-		if (errno != ENOENT)
-			pg_log(ctx, PG_FATAL, "\ncould not open file \"%s\" for reading\n",
-				   path);
-
-		return false;
-	}
-
-	close(fd);
-	return true;
-}
-
-
 /*
  * validate_exec()
  *
@@ -305,8 +303,8 @@ check_data_dir(migratorContext *ctx, const char *pg_data)
 {
 	char		subDirName[MAXPGPATH];
 	const char *requiredSubdirs[] = {"base", "global", "pg_clog",
-									 "pg_multixact", "pg_subtrans",
-									 "pg_tblspc", "pg_twophase", "pg_xlog"};
+		"pg_multixact", "pg_subtrans",
+	"pg_tblspc", "pg_twophase", "pg_xlog"};
 	bool		fail = false;
 	int			subdirnum;
 
@@ -317,7 +315,7 @@ check_data_dir(migratorContext *ctx, const char *pg_data)
 		snprintf(subDirName, sizeof(subDirName), "%s%c%s", pg_data,
 				 pathSeparator, requiredSubdirs[subdirnum]);
 
-		if ((stat(subDirName, &statBuf)) !=0)
+		if ((stat(subDirName, &statBuf)) != 0)
 		{
 			report_status(ctx, PG_WARNING, "check for %s warning:  %s",
 						  requiredSubdirs[subdirnum], getErrorText(errno));
@@ -334,27 +332,7 @@ check_data_dir(migratorContext *ctx, const char *pg_data)
 		}
 	}
 
-	if (fail)
-		return -1;
-	else
-		return 0;
+	return (fail) ? -1 : 0;
 }
 
 
-/*
- * getErrorText()
- *
- *	Returns the text of the error message for the given error number
- *
- *	This feature is factored into a separate function because it is
- *	likely to be system dependent
- */
-
-const char *
-getErrorText(int errNum)
-{
-#ifdef WIN32
-	_dosmaperr(GetLastError());
-#endif
-	return strdup(strerror(errNum));
-}
