@@ -243,22 +243,6 @@ get_pg_database_relfilenode(migratorContext *ctx, Cluster whichCluster)
 }
 
 
-/*
- * getDatabaseOIDs()
- *
- *	Returns a result set that lists the OID and name for each non-system
- *	database defined in the given server.
- */
-PGresult *
-getDatabaseOIDs(PGconn *conn)
-{
-	return PQexec(conn,
-				  "SELECT oid, datname "
-				  "FROM pg_catalog.pg_database "
-				  "WHERE datname != 'template0'");
-}
-
-
 /*
  * transfer_single_new_db()
  *
