@@ -284,27 +284,27 @@ test_server_conn(migratorContext *ctx, int timeout, Cluster whichCluster)
 void
 check_for_libpq_envvars(migratorContext *ctx)
 {
-	PQconninfoOption *d;
+	PQconninfoOption *option;
 	PQconninfoOption *start;
 	bool		found = false;
 
 	/* Get valid libpq env vars from the PQconndefaults function */
 
-	start = d = PQconndefaults();
+	start = option = PQconndefaults();
 
-	while (d->keyword != NULL)
+	while (option->keyword != NULL)
 	{
 		const char *value;
 
-		if ((value = getenv(d->envvar)) && strlen(value))
+		if (option->envvar && (value = getenv(option->envvar)) && strlen(value) > 0)
 		{
 			found = true;
 
 			pg_log(ctx, PG_WARNING,
-				   "libpq env var %-20s is currently set to: %s\n", d->envvar, value);
+				   "libpq env var %-20s is currently set to: %s\n", option->envvar, value);
 		}
 
-		d++;
+		option++;
 	}
 
 	/* Free the memory that libpq allocated on our behalf */
